==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/TextHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TextCellInfoDescriptionMetadata } from "./TextCellInfoDescriptionMetadata";
import { TextHeaderCellInfoDescription } from "./TextHeaderCellInfoDescription";
/**
 * @hidden
 */
export let TextHeaderCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class TextHeaderCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (TextHeaderCellInfoDescriptionMetadata.a == null) {
                TextHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TextHeaderCellInfoDescriptionMetadata.c(TextHeaderCellInfoDescriptionMetadata.a);
            }
            if (a.j(TextHeaderCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.y(TextHeaderCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            TextCellInfoDescriptionMetadata.c(a);
            a.item("IsColumnOptionsEnabled", "Boolean");
            a.item("SortIndicatorStyle", "ExportedType:string:SortIndicatorStyle");
            a.item("SortIndicatorStyle@names", "Default;FadingUpDownArrows;FadingSimpleUpDownArrows;Unset");
            a.item("ColumnOptionsIconAlignment", "ExportedType:string:ColumnOptionsIconAlignment");
            a.item("ColumnOptionsIconAlignment@names", "Unset;None;Opposite");
            a.item("ColumnOptionsIconColor", "Brush");
            a.item("ColumnOptionsIconBehavior", "ExportedType:string:ColumnOptionsIconBehavior");
            a.item("ColumnOptionsIconBehavior@names", "Unset;AlwaysVisible;AppearOnHover;AppearOnHoverAnimate");
        }
        static d(a) {
            TextHeaderCellInfoDescriptionMetadata.b(a);
            a.aa("TextHeaderCellInfo", () => new TextHeaderCellInfoDescription());
            a.z("TextHeaderCellInfo", TextHeaderCellInfoDescriptionMetadata.a);
        }
    }
    TextHeaderCellInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(TextHeaderCellInfoDescriptionMetadata, 'TextHeaderCellInfoDescriptionMetadata');
    TextHeaderCellInfoDescriptionMetadata.a = null;
    return TextHeaderCellInfoDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/TextHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TextCellInfoDescriptionMetadata } from "./TextCellInfoDescriptionMetadata";
import { TextHeaderCellInfoDescription } from "./TextHeaderCellInfoDescription";
/**
 * @hidden
 */
export let TextHeaderCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class TextHeaderCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (TextHeaderCellInfoDescriptionMetadata.a == null) {
                TextHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TextHeaderCellInfoDescriptionMetadata.c(TextHeaderCellInfoDescriptionMetadata.a);
            }
            if (a.k(TextHeaderCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.aa(TextHeaderCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            TextCellInfoDescriptionMetadata.c(a);
            a.item("IsColumnOptionsEnabled", "Boolean");
            a.item("SortIndicatorStyle", "ExportedType:string:SortIndicatorStyle");
            a.item("SortIndicatorStyle@names", "Default;FadingUpDownArrows;FadingSimpleUpDownArrows;Unset");
            a.item("ColumnOptionsIconAlignment", "ExportedType:string:ColumnOptionsIconAlignment");
            a.item("ColumnOptionsIconAlignment@names", "Unset;None;Opposite");
            a.item("ColumnOptionsIconColor", "Brush");
            a.item("ColumnOptionsIconBehavior", "ExportedType:string:ColumnOptionsIconBehavior");
            a.item("ColumnOptionsIconBehavior@names", "Unset;AlwaysVisible;AppearOnHover;AppearOnHoverAnimate");
        }
        static d(a) {
            TextHeaderCellInfoDescriptionMetadata.b(a);
            a.ac("TextHeaderCellInfo", () => new TextHeaderCellInfoDescription());
            a.ab("TextHeaderCellInfo", TextHeaderCellInfoDescriptionMetadata.a);
        }
    }
    TextHeaderCellInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(TextHeaderCellInfoDescriptionMetadata, 'TextHeaderCellInfoDescriptionMetadata');
    TextHeaderCellInfoDescriptionMetadata.a = null;
    return TextHeaderCellInfoDescriptionMetadata;
})();
